<?php
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 * @version   1.0
 * oceanwebguru.com
 * Languages: EN
 * PS version: 1.6
**/
use Symfony\Component\Translation\TranslatorInterface;

class CustomCheckoutStep extends AbstractCheckoutStep
{

    /** @var ocsignaturefieldforcheckout */
    protected $module;

    /** @var string $ocsignimgdata */
    protected $ocsignimgdata;

    public function __construct(
        Context $context,
        TranslatorInterface $translator,
        ocsignaturefieldforcheckout $module
    )
    {
        parent::__construct($context, $translator);
        $this->module = $module;
        $this->setTitle('Signature');
    }

    public function getDataToPersist()
    {
        return array(
            'ocsignimgdata' => $this->ocsignimgdata,
        );
    }

    public function restorePersistedData(array $data)
    {
        if (array_key_exists('ocsignimgdata', $data)) {
            $this->ocsignimgdata = $data['ocsignimgdata'];
        }

        return $this;
    }

    public function handleRequest(array $requestParameters = array())
    {
        //Si les informations sont postées assignation des valeurs
        if (isset($requestParameters['submitCustomCheckoutStep'])) {
            $this->ocsignimgdata = $requestParameters['ocsignimgdata'];
            $this->getCheckoutSession()->setIdSomethings($this->ocsignimgdata);
            $this->setComplete(true);

            if (version_compare(_PS_VERSION_, '1.7.6') > 0) {
                $this->setNextStepAsCurrent();
            } else {
                $this->setCurrent(false);
            }
        }

        return $this;
    }

    public function render(array $extraParams = [])
    {
        $defaultParams = array(
            'identifier' => 'test',
            'position' => 3,
            'title' => $this->getTitle(),
            'step_is_complete' => (int)$this->isComplete(),
            'step_is_reachable' => (int)$this->isReachable(),
            'step_is_current' => (int)$this->isCurrent(),
            'ocsignimgdata' => $this->ocsignimgdata,
            'OCSIGN_PADWIDTH' => Configuration::get('OCSIGN_PADWIDTH'),
            'OCSIGN_PADHEIGHT' => Configuration::get('OCSIGN_PADHEIGHT'),
        );

        $this->context->smarty->assign($defaultParams);

        return $this->module->display(
            _PS_MODULE_DIR_ . $this->module->name,
            'views/templates/front/checkout/testCheckoutStep.tpl'
        );
    }

}