<?php 
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 * @version   1.0
 * oceanwebguru.com
 * Languages: EN
 * PS version: 1.6
**/
use PrestaShop\PrestaShop\Core\Localization\Translator;

include_once _PS_MODULE_DIR_ . 'ocsignaturefieldforcheckout/ocsignaturefieldforcheckout.php';
include_once _PS_MODULE_DIR_ . 'ocsignaturefieldforcheckout/classes/checkout/CustomCheckoutStep.php';
if (!defined('_PS_VERSION_')) {
    exit;
}
class OcSignatureFieldforCheckout extends Module
{
    public function __construct()
    {
        $this->module_key = '456441635fa5c7dd8e87cabc800e7649';
        $this->name = 'ocsignaturefieldforcheckout';
        $this->tab = 'front_office_features';
        $this->version = '1.0.1';
        $this->author = 'Ajay Radadiya';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('OC Signature field for checkout page');
        $this->description = $this->l('Easy use Signature field for checkout');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        if (!parent::install() or
            !$this->registerHook('header') or
            !$this->registerHook('actionOrderStatusUpdate') or
            !$this->registerHook('displayorderconfirmation') or
            !$this->registerHook('displayBackOfficeHeader') or
            !$this->registerHook('displayAdminOrderMain') or
            !$this->registerHook('DisplayOrderDetail') or
            !$this->registerHook('actionCheckoutRender')) {
            return false;
        }

        return true;
    }

    public function hookActionCheckoutRender($params)
    {
        $context = Context::getContext();
        $context->shop->setContext(Shop::CONTEXT_ALL);
        $translator = $context->getTranslator();

        /** @var CheckoutProcess $process */
        $process = $params['checkoutProcess'];
        $steps = $process->getSteps();
        $module = Module::getInstanceByName('ocsignaturefieldforcheckout');
        $customCheckoutStep = new CustomCheckoutStep(
            $this->context,
            $translator,
            $module
        );

        $customCheckoutStep->setCheckoutProcess($process);

        $newSteps = [
            $steps[0],
            $steps[1],
            $customCheckoutStep,
            $steps[2],
            $steps[3]
        ];

        $process->setSteps($newSteps);
    }

    public function hookActionOrderStatusUpdate($params){
        $order_id = $params['id_order'];

        // Get the order object from the ID
        $order = new Order($order_id);

        // Define the SQL query to retrieve the checkout session data
        $sql = 'SELECT checkout_session_data FROM ' . _DB_PREFIX_ . 'cart WHERE id_cart = (SELECT id_cart FROM ' . _DB_PREFIX_ . 'orders WHERE id_order = ' . (int)$order_id . ')';

        // Execute the query and retrieve the checkout session data
        $result = Db::getInstance()->executeS($sql);
        $checkout_session_data = $result[0]['checkout_session_data'];
        $checkout_session_data_array = json_decode($checkout_session_data, true);
        $customstepdata = $checkout_session_data_array['custom-checkout-step'];
        $base64_image = explode(',', $customstepdata['ocsignimgdata'])[1];

        // Decode the base64 data and save it to a file
        $image_data = base64_decode($base64_image);
        $file_name = 'occussignature_'.$order_id.'.png';
        //$file_path = _PS_DOWNLOAD_DIR_ . $file_name;
        $newdirectory = _PS_IMG_DIR_ . 'signature/'; // Set the path to the new folder.
        if (!file_exists($newdirectory)) {
            mkdir($newdirectory, 0777, true); // Create the new folder with write permissions.
        }
        $file_pathview = $newdirectory . $file_name;
        //file_put_contents($file_path, $image_data);

        file_put_contents($file_pathview, $image_data);
        //require_once _PS_CLASS_DIR_ . 'Attachment.php';
        $attachment = new Attachment();
        $attachment->name = array((int)Configuration::get('PS_LANG_DEFAULT') => 'occussignature_'.$order_id);
        $attachment->file = $file_name;
        $attachment->mime = 'image/png';
        // $attachment->id_lang = (int)Context::getContext()->language->id;
        $attachment->file_path = $file_pathview;
        $attachment->description = 'My attachment description';
        $attachment->add();
    }

    public function hookDisplayOrderConfirmation($params)
    {
        $orderId = $_REQUEST['id_order'];
        $upload_path = Tools::getShopDomainSsl(true) . __PS_BASE_URI__ . 'img/signature/occussignature_' . $orderId . '.png';

        $this->context->smarty->assign(array(
            'upload_path' => $upload_path,
        ));

        return $this->display(__FILE__, '/views/templates/hook/ocdissignorder.tpl');
    }

    // In your module's hookDisplayAdminOrder() method, display the custom value in the admin order page
    public function hookDisplayAdminOrderMain($params)
    {
        $ocsign_display_onorder =  Configuration::get('OCSIGN_DISPLAY_ON_ORDER');
        if ($ocsign_display_onorder == 'yes') {
            $id_order = (int)$params['id_order'];
            $upload_path = Tools::getShopDomainSsl(true) . __PS_BASE_URI__ . 'img/signature/occussignature_' . $id_order . '.png';

            $this->context->smarty->assign(array(
                'upload_path' => $upload_path,
            ));

            return $this->display(__FILE__, 'views/templates/admin/order/customer/occheckout_adminorder.tpl');
        }
    }

    public function hookDisplayOrderDetail($params)
    {
        $ocsign_display_onorder =  Configuration::get('OCSIGN_DISPLAY_ON_ORDER');
        if ($ocsign_display_onorder == 'yes') {
            $id_order = $params['order']->id;
            $upload_path = Tools::getShopDomainSsl(true) . __PS_BASE_URI__ . 'img/signature/occussignature_' . $id_order . '.png';

            $this->context->smarty->assign(array(
                'upload_path' => $upload_path,
            ));

            return $this->display(__FILE__, 'views/templates/admin/order/customer/occheckout_adminorder.tpl');
        }
    }
    
    public function hookDisplayHeader()
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);
        $this->context->controller->addCSS($this->_path . '/views/css/ocsign_front.css', 'all');
        $this->context->controller->addJS($this->_path . '/views/js/digital_signature_pad.js', 'all');
        $myData = [
            'OCSIGN_BACK_CLR' => Configuration::get('OCSIGN_BACK_CLR'),
            'OCSIGN_TEXT_CLR' => Configuration::get('OCSIGN_TEXT_CLR'),
        ];
        $jsonData = json_encode($myData);
        $this->context->controller->registerJavascript(
            $this->name,
            $this->_path . 'views/js/ocfrontsignaturefield.js',
            [
                'position' => 'bottom',
                'priority' => 150,
                'server' => 'remote',
                'attributes' => 'async',
            ],
        );

        Media::addJsDef(['myData' => $myData]);
    }

    public function hookDisplayBackOfficeHeader()
    {
        if (Tools::getValue('configure') == 'ocsignaturefieldforcheckout') {
            $this->context->controller->addJS($this->_path . '/views/js/ocsign_admin.js', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/coloris.min.js', 'all');
            $this->context->controller->addCSS($this->_path . '/views/css/coloris.min.css', 'all');
        }
    }

    public function getParams()
    {
        $params = [
            'OCSIGN_BACK_CLR',
            'OCSIGN_TEXT_CLR',
            'OCSIGN_PADWIDTH',
            'OCSIGN_PADHEIGHT',
            'OCSIGN_DISPLAY_ON_ORDER',
        ];
        $params = Configuration::getMultiple($params);
        extract($params);
        $params['OCSIGN_BACK_CLR'] = ((empty($OCSIGN_BACK_CLR)) ? '#dddddd' : $OCSIGN_BACK_CLR);
        $params['OCSIGN_TEXT_CLR'] = ((empty($OCSIGN_TEXT_CLR)) ? '#000000' : $OCSIGN_TEXT_CLR);
        $params['OCSIGN_PADWIDTH'] = ((empty($OCSIGN_PADWIDTH)) ? '200' : $OCSIGN_PADWIDTH);
        $params['OCSIGN_PADHEIGHT'] = ((empty($OCSIGN_PADHEIGHT)) ? '200' : $OCSIGN_PADHEIGHT);
        $params['OCSIGN_DISPLAY_ON_ORDER'] = ((empty($OCSIGN_DISPLAY_ON_ORDER)) ? 'yes' : $OCSIGN_DISPLAY_ON_ORDER);

        return $params;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('OcSignTokenMessage')) {
            Configuration::updateValue('OCSIGN_BACK_CLR', Tools::getValue('OCSIGN_BACK_CLR'));
            Configuration::updateValue('OCSIGN_TEXT_CLR', Tools::getValue('OCSIGN_TEXT_CLR'));
            Configuration::updateValue('OCSIGN_PADWIDTH', Tools::getValue('OCSIGN_PADWIDTH'));
            Configuration::updateValue('OCSIGN_PADHEIGHT', Tools::getValue('OCSIGN_PADHEIGHT'));
            Configuration::updateValue('OCSIGN_DISPLAY_ON_ORDER', Tools::getValue('OCSIGN_DISPLAY_ON_ORDER'));
            $output .= $this->displayConfirmation($this->trans(
                    'Settings updated.',
                    [],
                    'Admin.Global',
                ));
        }
        if (isset($this->ps_version)) {
            $params = $this->getParams();
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true, false, $params);
        } else {
            $comurl = '&configure=' . $this->name . '&module_name=' . $this->name;
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true) . $comurl;
        }
        $currentPage = 'ocproductinquiry';
        $page = Tools::getValue('page');
        if (!empty($page)) {
            $currentPage = Tools::getValue('page');
        }
        $params = $this->getParams();
        $this->context->smarty->assign([
            'module_name' => $this->name,
            'module_version' => $this->version,
            'moduleAdminLink' => $moduleAdminLink,
            'module_display' => $this->displayName,
            'currentPage' => $currentPage,
            'ps_base_dir' => Tools::getHttpHost(true),
            'ps_version' => _PS_VERSION_,
            'isPs17' => isset($this->ps_version),
            'occheckoutsign_params' => $params,
        ]);
        $output .= '';

        return $output . $this->context->smarty->fetch($this->local_path . 'views/templates/admin/occheckout_sign_admin.tpl');
    }
}